"""
LogPy is a Python library for logic and relational programming.
"""

from core import run, eq, var, conde, membero, Relation, fact, facts, seteq

__version__ = '0.1.1'
